@@ -24,7 +24,6 @@ import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnTypeC
 import com.allen_sauer.gwt.log.client.Log;
 import com.google.gwt.event.logical.shared.SelectionEvent;
 import com.google.gwt.event.logical.shared.SelectionHandler;
-import com.google.gwt.i18n.client.DateTimeFormat;
 import com.google.gwt.user.client.ui.HTML;
 import com.google.web.bindery.event.shared.EventBus;
 import com.sencha.gxt.cell.core.client.ButtonCell.IconAlign;
@@ -48,26 +47,24 @@ import com.sencha.gxt.widget.core.client.form.validator.EmptyValidator;
 
 /**
  * 
- * @author "Giancarlo Panichi" <a
- *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * @author Giancarlo Panichi
+ *
  * 
  */
 public class MultiColumnExpressionPanel extends FramedPanel {
-	
+
 	private static final String WIDTH = "929px";
 	private static final String HEIGHT = "352px";
 	private static final String CONDITION_FIELD_WIDTH = "910px";
-	
+	private static final String RULE_CONDITION_FIELD_WIDTH = "914px";
+
 	private static final String ROWS_DELETE_HEIGHT = "388px";
-	private static final String RULE_HEIGHT= "312px";
-	
+	private static final String RULE_HEIGHT = "312px";
+
 	private static final String RULE_MULTI_CONDITION_WIDTH = "890px";
 	private static final String RULE_MULTI_CONDITION_HEIGHT = "228px";
-	
-	
-	private static final String RULE_DESCRIPTION_HEIGHT = "44px";
 
-	private DateTimeFormat sdf = DateTimeFormat.getFormat("yyyy-MM-dd HH:mm");
+	private static final String RULE_DESCRIPTION_HEIGHT = "44px";
 
 	private enum MultiColumnExpressionPanelType {
 		ColumnFilter, RowDeleteByExpression, Template, RuleOnTable;
@@ -98,12 +95,14 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 	/**
 	 * 
 	 * @param parent
-	 * @param columncreateOnRule
+	 *            parent
 	 * @param columns
+	 *            list of column
 	 * @param eventBus
+	 *            event bus
 	 */
-	public MultiColumnExpressionPanel(MultiColumnFilterDialog parent,
-			ArrayList<ColumnData> columns, EventBus eventBus) {
+	public MultiColumnExpressionPanel(MultiColumnFilterDialog parent, ArrayList<ColumnData> columns,
+			EventBus eventBus) {
 		super();
 		setWidth(WIDTH);
 		setHeight(HEIGHT);
@@ -116,13 +115,14 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 	/**
 	 * 
 	 * @param parent
-	 * @param column
+	 *            Parent
 	 * @param columns
+	 *            List of column
 	 * @param eventBus
+	 *            Event bus
 	 */
-	public MultiColumnExpressionPanel(
-			RowsDeleteByMultiColumnExpressionDialog parent,
-			ArrayList<ColumnData> columns, EventBus eventBus) {
+	public MultiColumnExpressionPanel(RowsDeleteByMultiColumnExpressionDialog parent, ArrayList<ColumnData> columns,
+			EventBus eventBus) {
 		super();
 		setWidth(WIDTH);
 		setHeight(ROWS_DELETE_HEIGHT);
@@ -135,12 +135,14 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 	/**
 	 * 
 	 * @param parent
-	 * @param column
+	 *            parent
+	 * @param columns
+	 *            list of column
 	 * @param eventBus
+	 *            event bus
 	 */
-	public MultiColumnExpressionPanel(
-			TemplateMultiColumnExpressionDialog parent,
-			ArrayList<ColumnData> columns, EventBus eventBus) {
+	public MultiColumnExpressionPanel(TemplateMultiColumnExpressionDialog parent, ArrayList<ColumnData> columns,
+			EventBus eventBus) {
 		super();
 		setWidth(WIDTH);
 		setHeight(HEIGHT);
@@ -153,10 +155,13 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 	/**
 	 * 
 	 * @param parent
-	 * @param eventBus
+	 *            parent
+	 * @param initialRuleDescriptionData
+	 *            initial rule description
+	 * @throws MultiColumnExpressionPanelException
+	 *             exception
 	 */
-	public MultiColumnExpressionPanel(RuleOnTableCreateDialog parent,
-			RuleDescriptionData initialRuleDescriptionData)
+	public MultiColumnExpressionPanel(RuleOnTableCreateDialog parent, RuleDescriptionData initialRuleDescriptionData)
 			throws MultiColumnExpressionPanelException {
 		super();
 		Log.debug("MultiColumnExpressionPanel");
@@ -167,22 +172,17 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 		this.initialRuleDescriptionData = initialRuleDescriptionData;
 		retrieveColumns();
 	}
-	
-	
-	
 
 	protected void retrieveColumns() throws MultiColumnExpressionPanelException {
 		if (initialRuleDescriptionData == null) {
 			Log.error("No rules description data present!");
-			throw new MultiColumnExpressionPanelException(
-					"No rules description data present!");
+			throw new MultiColumnExpressionPanelException("No rules description data present!");
 		}
 
 		TDRuleType tdRuleType = initialRuleDescriptionData.getTdRuleType();
 		if (tdRuleType == null) {
 			Log.error("No Rule Type present!");
-			throw new MultiColumnExpressionPanelException(
-					"No Rule Type present!");
+			throw new MultiColumnExpressionPanelException("No Rule Type present!");
 		}
 
 		if (tdRuleType instanceof TDRuleTableType) {
@@ -195,8 +195,7 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 				col.setId(ruleColumnPlaceHolderDescriptor.getId());
 				col.setColumnId(ruleColumnPlaceHolderDescriptor.getLabel());
 				col.setLabel(ruleColumnPlaceHolderDescriptor.getLabel());
-				col.setDataTypeName(ruleColumnPlaceHolderDescriptor
-						.getColumnDataType().getId());
+				col.setDataTypeName(ruleColumnPlaceHolderDescriptor.getColumnDataType().getId());
 				columns.add(col);
 			}
 
@@ -204,8 +203,7 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 
 		} else {
 			Log.error("No Table Rule Type present!");
-			throw new MultiColumnExpressionPanelException(
-					"No Table Rule Type present!");
+			throw new MultiColumnExpressionPanelException("No Table Rule Type present!");
 		}
 	}
 
@@ -216,7 +214,6 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 			setBodyBorder(false);
 			setHeaderVisible(false);
 
-			
 			FieldSet propertiesField = new FieldSet();
 			propertiesField.setHeadingText("Properties");
 			propertiesField.setCollapsible(false);
@@ -228,9 +225,10 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 			conditionsField = new FieldSet();
 			conditionsField.setHeadingText("Conditions");
 			conditionsField.setCollapsible(false);
-			conditionsField.setWidth(CONDITION_FIELD_WIDTH);
+			conditionsField.setWidth(RULE_CONDITION_FIELD_WIDTH);
 
-			conditionWidget = new ConditionOnMultiColumnWidget(columns,RULE_MULTI_CONDITION_WIDTH,RULE_MULTI_CONDITION_HEIGHT);
+			conditionWidget = new ConditionOnMultiColumnWidget(columns, RULE_MULTI_CONDITION_WIDTH,
+					RULE_MULTI_CONDITION_HEIGHT);
 			conditionsField.add(conditionWidget);
 
 			HBoxLayoutContainer flowButton = new HBoxLayoutContainer();
@@ -262,24 +260,19 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 				}
 			});
 
-			flowButton
-					.add(btnApply, new BoxLayoutData(new Margins(2, 4, 2, 4)));
+			flowButton.add(btnApply, new BoxLayoutData(new Margins(2, 4, 2, 4)));
+
+			flowButton.add(btnClose, new BoxLayoutData(new Margins(2, 4, 2, 4)));
 
-			flowButton
-					.add(btnClose, new BoxLayoutData(new Margins(2, 4, 2, 4)));
-			
 			VerticalLayoutContainer basicLayout = new VerticalLayoutContainer();
-			//basicLayout.setAdjustForScroll(true);
-			
-			basicLayout.add(propertiesField, new VerticalLayoutData(-1, -1,
-					new Margins(1)));
+			// basicLayout.setAdjustForScroll(true);
 
-			basicLayout.add(conditionsField, new VerticalLayoutData(-1, -1,
-					new Margins(1)));
+			basicLayout.add(propertiesField, new VerticalLayoutData(1, -1, new Margins(1)));
+
+			basicLayout.add(conditionsField, new VerticalLayoutData(-1, -1, new Margins(1)));
 
 			if (parentRuleOnTableCreateDialog != null) {
-				basicLayout.add(flowButton, new VerticalLayoutData(1, 36,
-						new Margins(5, 2, 5, 2)));
+				basicLayout.add(flowButton, new VerticalLayoutData(1, 36, new Margins(5, 2, 5, 2)));
 			}
 			add(basicLayout);
 
@@ -293,13 +286,12 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 				}
 			}
 		} catch (Throwable e) {
-			Log.debug("Error in createOnRule(): "+e.getLocalizedMessage());
+			Log.debug("Error in createOnRule(): " + e.getLocalizedMessage());
 			e.printStackTrace();
 		}
 	}
 
-	private void createRuleOnTableDecription(
-			VerticalLayoutContainer propertiesLayout) {
+	private void createRuleOnTableDecription(VerticalLayoutContainer propertiesLayout) {
 		ruleName = new TextField();
 		ruleName.addValidator(new EmptyValidator<String>());
 		ruleName.setToolTip("Rule Name");
@@ -313,16 +305,12 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 		ruleDescription.setHeight(RULE_DESCRIPTION_HEIGHT);
 		ruleDescription.setToolTip("Rule Description");
 		if (initialRuleDescriptionData != null) {
-			ruleDescription.setValue(initialRuleDescriptionData
-					.getDescription());
+			ruleDescription.setValue(initialRuleDescriptionData.getDescription());
 		}
-		FieldLabel ruleDescriptionLabel = new FieldLabel(ruleDescription,
-				"Rule Description");
+		FieldLabel ruleDescriptionLabel = new FieldLabel(ruleDescription, "Rule Description");
 
-		propertiesLayout.add(ruleNameLabel, new VerticalLayoutData(1, -1,
-				new Margins(0)));
-		propertiesLayout.add(ruleDescriptionLabel, new VerticalLayoutData(1,
-				-1, new Margins(0)));
+		propertiesLayout.add(ruleNameLabel, new VerticalLayoutData(1, -1, new Margins(0)));
+		propertiesLayout.add(ruleDescriptionLabel, new VerticalLayoutData(1, -1, new Margins(0)));
 
 	}
 
@@ -333,23 +321,18 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 				if (exp != null) {
 					String ruleNameS = ruleName.getCurrentValue();
 					String ruleDescriptionS = ruleDescription.getCurrentValue();
-					RuleDescriptionData ruleDescriptionData = new RuleDescriptionData(
-							0, ruleNameS, ruleDescriptionS,
-							sdf.format(new Date()), null, null,
-							RuleScopeType.TABLE, exp,
+					RuleDescriptionData ruleDescriptionData = new RuleDescriptionData(0, ruleNameS, ruleDescriptionS,
+							new Date(), null, null, RuleScopeType.TABLE, exp,
 							initialRuleDescriptionData.getTdRuleType());
 					return ruleDescriptionData;
 				} else {
-					throw new MultiColumnExpressionPanelException(
-							"Enter a valid condition!");
+					throw new MultiColumnExpressionPanelException("Enter a valid condition!");
 				}
 			} else {
-				throw new MultiColumnExpressionPanelException(
-						"Enter a valid description for the rule!");
+				throw new MultiColumnExpressionPanelException("Enter a valid description for the rule!");
 			}
 		} else {
-			throw new MultiColumnExpressionPanelException(
-					"Enter a valid name for the rule!");
+			throw new MultiColumnExpressionPanelException("Enter a valid name for the rule!");
 		}
 
 	}
@@ -361,7 +344,6 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 		setBodyBorder(false);
 		setHeaderVisible(false);
 
-		
 		HBoxLayoutContainer flowButton = new HBoxLayoutContainer();
 		flowButton.setHBoxLayoutAlign(HBoxLayoutAlign.MIDDLE);
 		flowButton.setPack(BoxLayoutPack.CENTER);
@@ -403,16 +385,13 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 		flowButton.add(btnApply, new BoxLayoutData(new Margins(2, 4, 2, 4)));
 
 		flowButton.add(btnClose, new BoxLayoutData(new Margins(2, 4, 2, 4)));
-		
-		
+
 		VerticalLayoutContainer basicLayout = new VerticalLayoutContainer();
-		//basicLayout.setAdjustForScroll(true);
+		// basicLayout.setAdjustForScroll(true);
 		// basicLayout.setScrollMode(ScrollMode.AUTO); Set In GXT 3.0.1
 
-		basicLayout.add(conditionsField, new VerticalLayoutData(-1, -1,
-				new Margins(1)));
-		basicLayout.add(flowButton, new VerticalLayoutData(1, 36, new Margins(
-				5, 2, 5, 2)));
+		basicLayout.add(conditionsField, new VerticalLayoutData(-1, -1, new Margins(1)));
+		basicLayout.add(flowButton, new VerticalLayoutData(1, 36, new Margins(5, 2, 5, 2)));
 		add(basicLayout);
 
 	}
@@ -423,7 +402,6 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 		setBodyBorder(false);
 		setHeaderVisible(false);
 
-		
 		HBoxLayoutContainer flowButton = new HBoxLayoutContainer();
 		flowButton.setHBoxLayoutAlign(HBoxLayoutAlign.MIDDLE);
 		flowButton.setPack(BoxLayoutPack.CENTER);
@@ -463,13 +441,10 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 		flowButton.add(btnApply, new BoxLayoutData(new Margins(2, 4, 2, 4)));
 		flowButton.add(btnClose, new BoxLayoutData(new Margins(2, 4, 2, 4)));
 
-	
 		VerticalLayoutContainer basicLayout = new VerticalLayoutContainer();
-		//basicLayout.setAdjustForScroll(true);
-		basicLayout.add(conditionsField, new VerticalLayoutData(-1, -1,
-				new Margins(0)));
-		basicLayout.add(flowButton, new VerticalLayoutData(1, 36, new Margins(
-				5, 2, 5, 2)));
+		// basicLayout.setAdjustForScroll(true);
+		basicLayout.add(conditionsField, new VerticalLayoutData(-1, -1, new Margins(0)));
+		basicLayout.add(flowButton, new VerticalLayoutData(1, 36, new Margins(5, 2, 5, 2)));
 
 		add(basicLayout);
 
@@ -489,14 +464,13 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 		conditionsField.setHeadingText("Conditions");
 		conditionsField.setCollapsible(false);
 		conditionsField.setWidth(CONDITION_FIELD_WIDTH);
-		
+
 		conditionWidget = new ConditionOnMultiColumnWidget(columns);
 		Log.debug("ConditionWidget" + conditionWidget);
 		conditionsField.add(conditionWidget);
 
 		btnApply = new TextButton("Delete");
-		btnApply.setIcon(ExpressionResources.INSTANCE
-				.tableRowDeleteByExpression());
+		btnApply.setIcon(ExpressionResources.INSTANCE.tableRowDeleteByExpression());
 		btnApply.setIconAlign(IconAlign.RIGHT);
 		btnApply.setToolTip("Delete rows");
 		btnApply.addSelectHandler(new SelectHandler() {
@@ -523,11 +497,9 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 		flowButton.add(btnClose, new BoxLayoutData(new Margins(2, 4, 2, 4)));
 
 		VerticalLayoutContainer basicLayout = new VerticalLayoutContainer();
-		
-		basicLayout.add(conditionsField, new VerticalLayoutData(-1, -1,
-				new Margins(1)));
-		basicLayout.add(flowButton, new VerticalLayoutData(1, 36, new Margins(
-				5, 2, 5, 2)));
+
+		basicLayout.add(conditionsField, new VerticalLayoutData(-1, -1, new Margins(1)));
+		basicLayout.add(flowButton, new VerticalLayoutData(1, 36, new Margins(5, 2, 5, 2)));
 
 		add(basicLayout);
 
@@ -537,14 +509,11 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 		if (column == null) {
 
 		} else {
-			ColumnTypeCode typeCode = ColumnTypeCode
-					.getColumnTypeCodeFromId(column.getTypeCode());
+			ColumnTypeCode typeCode = ColumnTypeCode.getColumnTypeCodeFromId(column.getTypeCode());
 			HTML errorMessage;
 			if (typeCode == null) {
-				errorMessage = new HTML(
-						"This column has column data type null!");
-				UtilsGXT3.alert("Error",
-						"This column has column data type null!!");
+				errorMessage = new HTML("This column has column data type null!");
+				UtilsGXT3.alert("Error", "This column has column data type null!!");
 				return;
 			}
 
@@ -559,18 +528,14 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 				break;
 			case DIMENSION:
 			case TIMEDIMENSION:
-				errorMessage = new HTML(
-						"This type of column is not supported for now!");
+				errorMessage = new HTML("This type of column is not supported for now!");
 				add(errorMessage);
-				UtilsGXT3.alert("Error",
-						"This type of column is not supported for now!");
+				UtilsGXT3.alert("Error", "This type of column is not supported for now!");
 				break;
 			default:
-				errorMessage = new HTML(
-						"This type of column is not supported for now!");
+				errorMessage = new HTML("This type of column is not supported for now!");
 				add(errorMessage);
-				UtilsGXT3.alert("Error",
-						"This type of column is not supported for now!");
+				UtilsGXT3.alert("Error", "This type of column is not supported for now!");
 				break;
 
 			}
@@ -619,8 +584,7 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 			condContainer.setExp(exp);
 			exWrapper = new ExpressionWrapper(null, null, condContainer);
 
-			ExpressionWrapperNotification expressionWrapperNotification = new ExpressionWrapperNotification(
-					exWrapper);
+			ExpressionWrapperNotification expressionWrapperNotification = new ExpressionWrapperNotification(exWrapper);
 			Log.debug("Apply: " + expressionWrapperNotification);
 			parentTemplateDialog.onExpression(expressionWrapperNotification);
 			break;
@@ -682,8 +646,7 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 
 	}
 
-	public RuleDescriptionData getRuleOnTable()
-			throws MultiColumnExpressionPanelException {
+	public RuleDescriptionData getRuleOnTable() throws MultiColumnExpressionPanelException {
 		if (!conditionWidget.isEnabled()) {
 			throw new MultiColumnExpressionPanelException("Fill all field!");
 		}
@@ -694,8 +657,7 @@ public class MultiColumnExpressionPanel extends FramedPanel {
 			exp = conditionWidget.getExpression();
 		} catch (ConditionTypeMapException e) {
 			Log.debug(e.getLocalizedMessage());
-			throw new MultiColumnExpressionPanelException(
-					e.getLocalizedMessage());
+			throw new MultiColumnExpressionPanelException(e.getLocalizedMessage());
 		}
 		RuleDescriptionData ruleDescriptionData = retrieveRuleDescriptionData(exp);
 		return ruleDescriptionData;
